@@ -36,12 +36,12 @@ def addTask(tasks: List[Task], db: Session = Depends(get_db)):
 
 
 @app.delete(path="/task")
-def deleteTask(pid: int, db: Session = Depends(get_db)):
+def deleteTask(pid: str, db: Session = Depends(get_db)):
     return crud.deleteTask(db, pid=pid)
 
 
 @app.get(path="/task")
-def getTask(pid: int=None, skip: int=0, limit: int=1000, db: Session = Depends(get_db)):
+def getTask(pid: str=None, skip: int=0, limit: int=1000, db: Session = Depends(get_db)):
     return crud.getTask(db, pid=pid, skip=skip, limit=limit)
 
 
